"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTouchController = void 0;
const React = require("react");
const useTouchController = ({ pressEventDuration = 200, onPress, onHoldEnd, onHoldStart, }) => {
    const [timestamp, setTimestamp] = React.useState(0);
    const timer = React.useRef();
    const onPressIn = React.useCallback((event) => {
        clearTimeout(timer.current);
        setTimestamp(Date.now());
        timer.current = setTimeout(() => onHoldStart(event), pressEventDuration);
    }, [onHoldStart, pressEventDuration]);
    const onPressOut = React.useCallback((event) => {
        const isPressEvent = (timestamp + pressEventDuration) >= Date.now();
        if (isPressEvent) {
            clearTimeout(timer.current);
            return onPress(event);
        }
        onHoldEnd(event);
    }, [timestamp, pressEventDuration, onPress, onHoldEnd]);
    return {
        onPressIn,
        onPressOut,
    };
};
exports.useTouchController = useTouchController;
